/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.oauth2.provider.scope.liferay;

import org.osgi.framework.Bundle;

/**
 * Represents an application exported scope for Liferay's OAuth2 Provider
 * framework.
 *
 * @author Carlos Sierra Andrés
 */
public interface LiferayOAuth2Scope {

	/**
	 * Returns the name of the application that provides the scope. This usually
	 * refers to the JAX-RS application name.
	 *
	 * @return the non-<code>null</code> application name
	 */
	public String getApplicationName();

	/**
	 * Returns the OSGi bundle context where the application and scope are
	 * published.
	 *
	 * @return the non-<code>null</code> OSGi bundle
	 */
	public Bundle getBundle();

	/**
	 * Returns the scope name as registered in the OAuth2 Provider framework.
	 *
	 * @return the non-<code>null</code> scope name
	 */
	public String getScope();

}